-- Holds custom descriptions for view-item-info
-- By PeridexisErrant

-- The following people contributed descriptions:
-- Raideau, PeridexisErrant, /u/Puffin4Tom, /u/KroyMortlach
-- /u/genieus, /u/TeamsOnlyMedic, /u/johny5w, /u/DerTanni

if not moduleMode then
    print("scripts/item-descriptions.lua is a content library; calling it does nothing.")
end

local help --[[
This script has a single function: to return a custom description for every
vanilla item in the game.

If "raw/scripts/item-descriptions.lua" exists, it will entirely replace this one.
Instead, mods should use "raw/scripts/more-item-descriptions.lua" to add content or replace
descriptions on a case-by-case basis.  If an item description cannot be found in
the latter script, view-item-info will fall back to the former.
]]

-- see http://dwarffortresswiki.org/index.php/cv:Item_token
descriptions = {
    AMULET = {  "An item of jewellery worn around the neck for it's aesthetic value.",
                "An amulet does not interfere with wearing other equipment."},
    ANIMALTRAP = {
                "This tiny trap is used by your trappers to catch vermin. Some dwarves",
                "like vermin as pets - if your cats don't get them first."},
    ANVIL = {   "An essential component of the forge."},
    ARMORSTAND = {
                "A rack for the storage of military equipment, specifically armor.",
                "It is required by some nobles, and can be used to create a barracks."},
    BACKPACK = {"A backpack can be used by militia to carry rations in the field.",
                "In Adventure mode, backpacks can be used to carry more equipment."},
    BALLISTAARROWHEAD = {},
    BALLISTAPARTS = {},
    BAR = {},
    BARREL = {  "A hollow cylinder with a removable lid. It is used to hold liquids,",
                "food, and seeds. It can be made from metal or wood, and is replaceable",
                "with a rock pot. A barrel (or rock pot) is needed to brew drinks."},
    BED = {     "A pallet for dwarves to sleep on, which must be made from wood.",
                "It prevents the stress of sleeping on the ground, and can be used",
                "to designate a bedroom (used by one dwarf or couple), a dormitory",
                "(used by multiple dwarves), or a barracks (used by a military",
                "squad for training or sleep)."},
    BIN = {     "A container for the storage of ammunition, armor and weapons, bars,",
                "blocks, cloth and leather, coins, finished goods and gems. It can",
                "be used to carry multiple items to the Trade Depot at once.",
                "A bin can be made from wood or forged from metal."},
    BLOCKS = {  "Blocks can be used for constructions in place of raw materials such",
                "as logs or bars.  Cutting boulders into blocks gives four times as",
                "many items, all of which are lighter for faster hauling and yield",
                "smooth constructions."},
    BOX = {     "A container for storing dwarves' items. They are required by nobles,",
                "and will increase the value of rooms they are placed in. Also",
                "required to store hospital supplies. They can be made from stone or",
                "metal (coffers), wood (chests),or textiles or leather (bags)."},
    BUCKET = {  "A small cylindrical or conical container for holding and carrying",
                "small amounts of liquid such as water or lye. They are used by",
                "dwarves to give water to other dwarves, to store lye, and are",
                "required to build wells and certain workshops. They can be made",
                "from wood or metal."},
    BOOK = {    "It's a book. Some books contain the secrets of life and death, and",
                "reading them in Adventure mode will give you necromantic powers."},
    BOULDER = { "Mining may yield loose stones for industry.  There are four categories:",
                "non-economic stones for building materials,  ores for metal industry,",
                "gems, and special-purpose economic stones like flux, coal and lignite."},
    BRACELET = {"A bracelet is an item of jewellery worn on the hands."},
    CABINET = {},
    CAGE = {},
    CATAPULTPARTS = {},
    CHAIN = {   "A chain made of metal. A chain or rope is required to build a well.",
                "Due to the marvels of dwarven engineering, a single chain can be used",
                "for a well of any depth. Chains are also used to create restraints",
                "for prisoners or animals."},
    CHAIR = {},
    CLOTH = {},
    COFFIN = {},
    COIN = {},
    CROWN = {   "A crown may be worn as headgear, or on top of a helmet.  Although",
                "usually just decorative or symbolic, crowns sometimes deflect attacks."},
    CRUTCH = {},
    DOOR = {},
    EARRING = { "Earrings are decorative jewellery.  Eleven can be worn on each ear."},
    FIGURINE = {},
    FLASK = {},
    FLOODGATE = {},
    GOBLET = {},
    GRATE = {},
    HATCH_COVER = {},
    ITEM_AMMO_ARROWS = {
                "Ammunition for bows, which are primarily used by elves."},
    ITEM_AMMO_BOLTS = {
                "Ammunition for crossbows, which are a dwarf's preferred ranged weapon.",
                "It is not recommended to store bolts in bins, due to pickup bugs."},
    ITEM_ARMOR_BREASTPLATE = {},
    ITEM_ARMOR_CAPE = {},
    ITEM_ARMOR_CLOAK = {},
    ITEM_ARMOR_COAT = {},
    ITEM_ARMOR_DRESS = {},
    ITEM_ARMOR_LEATHER = {
                "Leather armor is light and covers both arms and legs",
                "in addition to body"},
    ITEM_ARMOR_MAIL_SHIRT = {},
    ITEM_ARMOR_ROBE = {},
    ITEM_ARMOR_SHIRT = {},
    ITEM_ARMOR_TOGA = {},
    ITEM_ARMOR_TUNIC = {},
    ITEM_ARMOR_VEST = {},
    ITEM_FOOD_BISCUITS = {
                "Biscuits are the lowest tier of meals that can be prepared by your",
                "dwarves. They are made in a kitchen with the 'Prepare Easy Meal' order",
                "and use two ingredients. Preparing easy meals is the easiest way to,",
                "get experience for you cooks, but the larger volume produced means more",
                "hauling to take them to storage."},
    ITEM_FOOD_ROAST = {
                "Roasts are the highest tier of meals that can be prepared by your ",
                "dwarves. They are made in a kitchen with the 'Prepare Lavish Meal'",
                "order, and use four ingredients. As there are more ingredients, there",
                "is a better chance that a dwarf will like at least one ingredient."},
    ITEM_FOOD_STEW = {
                "Stews are the middle tier of meals that can be prepared by your ",
                "dwarves. They are made in a kitchen with the 'Prepare Fine Meal' order,",
                "and use three ingredients. They provide more food than Biscuits,",
                "but are less valuable than Roasts."},
    ITEM_GLOVES_GAUNTLETS = {},
    ITEM_GLOVES_GLOVES = {},
    ITEM_GLOVES_MITTENS = {},
    ITEM_HELM_CAP = {},
    ITEM_HELM_HELM = {},
    ITEM_HELM_HOOD = {},
    ITEM_HELM_MASK = {},
    ITEM_HELM_SCARF_HEAD = {},
    ITEM_HELM_TURBAN = {},
    ITEM_HELM_VEIL_FACE = {},
    ITEM_HELM_VEIL_HEAD = {},
    ITEM_INSTRUMENT_DRUM = {},
    ITEM_INSTRUMENT_FLUTE = {},
    ITEM_INSTRUMENT_HARP = {},
    ITEM_INSTRUMENT_PICCOLO = {},
    ITEM_INSTRUMENT_TRUMPET = {},
    ITEM_PANTS_BRAIES = {},
    ITEM_PANTS_GREAVES = {},
    ITEM_PANTS_LEGGINGS = {},
    ITEM_PANTS_LOINCLOTH = {},
    ITEM_PANTS_PANTS = {},
    ITEM_PANTS_SKIRT = {},
    ITEM_PANTS_SKIRT_LONG = {},
    ITEM_PANTS_SKIRT_SHORT = {},
    ITEM_PANTS_THONG = {},
    ITEM_SHIELD_BUCKLER = {},
    ITEM_SHIELD_SHIELD = {},
    ITEM_SHOES_BOOTS = {},
    ITEM_SHOES_BOOTS_LOW = {},
    ITEM_SHOES_CHAUSSE = {},
    ITEM_SHOES_SANDAL = {},
    ITEM_SHOES_SHOES = {},
    ITEM_SHOES_SOCKS = {},
    ITEM_SIEGEAMMO_BALLISTA = {},
    ITEM_TOOL_BOWL = {},
    ITEM_TOOL_CAULDRON = {},
    ITEM_TOOL_FORK_CARVING = {},
    ITEM_TOOL_HIVE = {},
    ITEM_TOOL_HONEYCOMB = {},
    ITEM_TOOL_JUG = {},
    ITEM_TOOL_KNIFE_BONING = {},
    ITEM_TOOL_KNIFE_CARVING = {},
    ITEM_TOOL_KNIFE_MEAT_CLEAVER = {},
    ITEM_TOOL_KNIFE_SLICING = {},
    ITEM_TOOL_LADLE = {},
    ITEM_TOOL_LARGE_POT = {},
    ITEM_TOOL_MINECART = {},
    ITEM_TOOL_MORTAR = {},
    ITEM_TOOL_NEST_BOX = {},
    ITEM_TOOL_PESTLE = {},
    ITEM_TOOL_POUCH = {},
    ITEM_TOOL_SCALE_SHARD = {},
    ITEM_TOOL_STEPLADDER = {
                "A small stepladder. If you have one of these, you can use zones to",
                "assign your dwarfs to pick fruit from certain trees."},
    ITEM_TOOL_WHEELBARROW = {},
    ITEM_TOY_AXE = {
                "A small toy axe without an edge. Useless except as a trade good."},
    ITEM_TOY_BOAT = {
                "A tiny model of a boat. Only good for trade."},
    ITEM_TOY_HAMMER = {
                "A toy hammer. It's only use is to sell."},
    ITEM_TOY_MINIFORGE = {
                "A model of a blacksmith's forge that dwarf children love.",
                "Only useful as a trade good."},
    ITEM_TOY_PUZZLEBOX = {
                "A perplexing toy that dwarves of all ages enjoy.",
                "It's only use is as a trade good."},
    ITEM_TRAPCOMP_ENORMOUSCORKSCREW = {
                "A massive screw-like object. Can be used to make a pump,",
                "or as a component in a trap."},
    ITEM_TRAPCOMP_GIANTAXEBLADE = {},
    ITEM_TRAPCOMP_LARGESERRATEDDISC = {},
    ITEM_TRAPCOMP_MENACINGSPIKE = {},
    ITEM_TRAPCOMP_SPIKEDBALL = {},
    ITEM_WEAPON_AXE_BATTLE = {
                "A battle axe is an edged weapon: essentially a sharp blade",
                "mounted along the end of a short and heavy handle.",
                "",
                "Dwarves can forge battle axes out of any weapon-grade metal,",
                "though those with superior edge properties are more effective.",
                "",
                "A battle axe may also be used as a tool for chopping down trees."},
    ITEM_WEAPON_AXE_GREAT = {},
    ITEM_WEAPON_AXE_TRAINING = {
                "As a battleaxe made from wood, this practise weapon is useful for",
                "training recruits.  Thanks to good craftsdwarfship, it can also",
                "be used to cut down trees."},
    ITEM_WEAPON_BLOWGUN = {},
    ITEM_WEAPON_BOW = {
                "Bows are the preferred ranged weapon for elves and goblins, and",
                "shoot arrows as projectiles. As they are a foreign weapon, they",
                "cannot be made in your fort. In melee, bowmen will use their bow as",
                "a weapon, training the swordsman skill."},
    ITEM_WEAPON_CROSSBOW = {
                "The favoured ranged weapon of choice for any dwarf, crossbows can be",
                "made of wood, bones or metal, and shoot bolts as projectiles. Hunters",
                "or marks-dwarves that run out of ammunition will use their crossbow",
                "as a melee weapon, training the hammerdwarf skill."},
    ITEM_WEAPON_DAGGER_LARGE = {},
    ITEM_WEAPON_FLAIL = {},
    ITEM_WEAPON_HALBERD = {
                "A halberd is a foreign weapon, and cannot be made by your dwarves.",
                "Even the largest and strongest dwarves cannot use a halberd, making",
                "them useless in military terms. However, they can be melted down to",
                "provide metal bars, somewhat redeeming them."},
    ITEM_WEAPON_HAMMER_WAR = {},
    ITEM_WEAPON_MACE = {},
    ITEM_WEAPON_MAUL = {},
    ITEM_WEAPON_MORNINGSTAR = {},
    ITEM_WEAPON_PICK = {
                "The most important item for a beginning fortress, a pick can",
                "get a party underground.  Also crucial mining for stone or",
                "metals, expansion of living space, and so on.",
                "",
                "A pick is also useful as a weapon, though putting miners in the",
                "military causes equipment clashes."},
    ITEM_WEAPON_PIKE = {},
    ITEM_WEAPON_SCIMITAR = {},
    ITEM_WEAPON_SCOURGE = {},
    ITEM_WEAPON_SPEAR = {},
    ITEM_WEAPON_SPEAR_TRAINING = {},
    ITEM_WEAPON_SWORD_2H = {},
    ITEM_WEAPON_SWORD_LONG = {},
    ITEM_WEAPON_SWORD_SHORT = {},
    ITEM_WEAPON_SWORD_SHORT_TRAINING = {
                "A wooden training sword, this has no sharp edges and thus presents",
                "little risk of injury to your dwarfs. Military dwarfs can become",
                "attached to them, and refuse to swap them for weapons that cause",
                "actual injury to your enemies."},
    ITEM_WEAPON_WHIP = {
                "A highly effective weapon known to cause large amounts of pain.",
                "It cannot be forged by dwarves."},
    MEAT = {    "Butchering an animal gives meat, the amount depending on the size",
                "of the butchered animal. Along with plants, meat is the",
                "backbone of every food industry."},
    MILLSTONE = {},
    ORTHOPEDIC_CAST = {
                "Casts are made from plaster, and are used to keep broken bones in",
                "place until they are healed. Applying a cast requires a bucket,",
                "cloth and a water source."},
    PIPE_SECTION = {
                "An enormous piece of pipe, it is a part of a screw pump."},
    QUERN = {},
    QUIVER = {},
    RING = {    "A ring is an item of jewellery, which does not interfere with",
                "wearing other equipment.  Eleven rings can be worn on each finger",
                "or toe, for a maximum of 220 rings."},
    ROCK = {    "A small rock, sharpened as a weapon in Adventure mode."},
    ROUGH = {},
    SCEPTER = {},
    SKIN_TANNED = {},
    SLAB = {    "A memorial stone, used to quiet restless ghost when engraved with",
                "the name of the deceased and built."},
    SMALLGEM = {},
    SPLINT = {  "Splints are used to immobilise fractured limbs. They are made out of",
                "wood or metal, and allow dwarfs to leave the hospital and continue",
                "their normal jobs. Splints are applied with the bonedoctor skill."},
    STATUE = {},
    TABLE = {},
    THREAD = {},
    TOTEM = {},
    TRACTION_BENCH = {},
    TRAPPARTS = {
                "Used to build traps, levers and other machines."},
    WEAPONRACK = {},
    WINDOW = {},
    WOOD = {}
}
